Class: Google::Cloud::VectorSearch::V1::AggregateDataObjectsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#aggregate::Google::Cloud::VectorSearch::V1::AggregationMethod

Returns Required. The aggregation method to apply to the query.

Returns:



266
267
268
269
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 266

class AggregateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filter::Google::Protobuf::Struct

Returns Optional. A JSON filter expression, e.g. {"genre": \{"$eq": "sci-fi"}}, represented as a google.protobuf.Struct.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. A JSON filter expression, e.g. {"genre": \{"$eq": "sci-fi"}}, represented as a google.protobuf.Struct.



266
267
268
269
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 266

class AggregateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the Collection for which to query. Format: projects/{project}/locations/{location}/collections/{collection}.

Returns:

  • (::String)

    Required. The resource name of the Collection for which to query. Format: projects/{project}/locations/{location}/collections/{collection}



266
267
268
269
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 266

class AggregateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end