Class: Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The resource name of the Collection to create the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}. The parent field in the CreateDataObjectRequest messages must match this field.

Returns:

  • (::String)

    Required. The resource name of the Collection to create the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}. The parent field in the CreateDataObjectRequest messages must match this field.



57
58
59
60
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 57

class BatchCreateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requests::Array<::Google::Cloud::VectorSearch::V1::CreateDataObjectRequest>

Returns Required. The request message specifying the resources to create. A maximum of 1000 DataObjects can be created in a batch.

Returns:



57
58
59
60
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 57

class BatchCreateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end