Class: Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

A request to perform a batch of search operations.

Defined Under Namespace

Classes: CombineResultsOptions

Instance Attribute Summary collapse

Instance Attribute Details

#combine::Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsRequest::CombineResultsOptions

Returns Optional. Options for combining the results of the batch search operations.

Returns:



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 337

class BatchSearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for combining the results of the batch search operations.
  # @!attribute [rw] ranker
  #   @return [::Google::Cloud::VectorSearch::V1::Ranker]
  #     Required. The ranker to use for combining the results.
  # @!attribute [rw] output_fields
  #   @return [::Google::Cloud::VectorSearch::V1::OutputFields]
  #     Optional. Mask specifying which fields to return.
  # @!attribute [rw] top_k
  #   @return [::Integer]
  #     Optional. The number of results to return. If not set, a default value
  #     will be used.
  class CombineResultsOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parent::String

Returns Required. The resource name of the Collection for which to search. Format: projects/{project}/locations/{location}/collections/{collection}.

Returns:

  • (::String)

    Required. The resource name of the Collection for which to search. Format: projects/{project}/locations/{location}/collections/{collection}



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 337

class BatchSearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for combining the results of the batch search operations.
  # @!attribute [rw] ranker
  #   @return [::Google::Cloud::VectorSearch::V1::Ranker]
  #     Required. The ranker to use for combining the results.
  # @!attribute [rw] output_fields
  #   @return [::Google::Cloud::VectorSearch::V1::OutputFields]
  #     Optional. Mask specifying which fields to return.
  # @!attribute [rw] top_k
  #   @return [::Integer]
  #     Optional. The number of results to return. If not set, a default value
  #     will be used.
  class CombineResultsOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#searches::Array<::Google::Cloud::VectorSearch::V1::Search>

Returns Required. A list of search requests to execute in parallel.

Returns:



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 337

class BatchSearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for combining the results of the batch search operations.
  # @!attribute [rw] ranker
  #   @return [::Google::Cloud::VectorSearch::V1::Ranker]
  #     Required. The ranker to use for combining the results.
  # @!attribute [rw] output_fields
  #   @return [::Google::Cloud::VectorSearch::V1::OutputFields]
  #     Optional. Mask specifying which fields to return.
  # @!attribute [rw] top_k
  #   @return [::Integer]
  #     Optional. The number of results to return. If not set, a default value
  #     will be used.
  class CombineResultsOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end