Class: Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

A response from a batch search operation.

Instance Attribute Summary collapse

Instance Attribute Details

#results::Array<::Google::Cloud::VectorSearch::V1::SearchDataObjectsResponse> (readonly)

Returns Output only. A list of search responses, one for each request in the batch. If a ranker is used, a single ranked list of results is returned.

Returns:



381
382
383
384
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 381

class BatchSearchDataObjectsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end