Class: Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The resource name of the Collection to update the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}. The parent field in the UpdateDataObjectRequest messages must match this field.

Returns:

  • (::String)

    Required. The resource name of the Collection to update the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}. The parent field in the UpdateDataObjectRequest messages must match this field.



110
111
112
113
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 110

class BatchUpdateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requests::Array<::Google::Cloud::VectorSearch::V1::UpdateDataObjectRequest>

Returns Required. The request message specifying the resources to update. A maximum of 1000 DataObjects can be updated in a batch.

Returns:



110
111
112
113
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 110

class BatchUpdateDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end