Class: Google::Cloud::VectorSearch::V1::CreateCollectionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::CreateCollectionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Message for creating a Collection
Instance Attribute Summary collapse
-
#collection ⇒ ::Google::Cloud::VectorSearch::V1::Collection
Required.
-
#collection_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#collection ⇒ ::Google::Cloud::VectorSearch::V1::Collection
Returns Required. The resource being created.
193 194 195 196 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 193 class CreateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#collection_id ⇒ ::String
Returns Required. ID of the Collection to create.
The id must be 1-63 characters long, and comply with
RFC1035.
Specifically, it must be 1-63 characters long and match the regular
expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.
193 194 195 196 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 193 class CreateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Value for parent.
193 194 195 196 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 193 class CreateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
193 194 195 196 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 193 class CreateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |