Class: Google::Cloud::VectorSearch::V1::CreateDataObjectRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb

Overview

Request message for DataObjectService.CreateDataObject.

Instance Attribute Summary collapse

Instance Attribute Details

#data_object::Google::Cloud::VectorSearch::V1::DataObject

Returns Required. The DataObject to create.

Returns:



40
41
42
43
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 40

class CreateDataObjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_object_id::String

Returns Required. The id of the dataObject to create. The id must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.

Returns:

  • (::String)

    Required. The id of the dataObject to create. The id must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.



40
41
42
43
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 40

class CreateDataObjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the Collection to create the DataObject in. Format: projects/{project}/locations/{location}/collections/{collection}.

Returns:

  • (::String)

    Required. The resource name of the Collection to create the DataObject in. Format: projects/{project}/locations/{location}/collections/{collection}



40
41
42
43
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 40

class CreateDataObjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end