Class: Google::Cloud::VectorSearch::V1::CreateIndexRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb

Overview

Message for creating an Index.

Instance Attribute Summary collapse

Instance Attribute Details

#index::Google::Cloud::VectorSearch::V1::Index

Returns Required. The resource being created.

Returns:



355
356
357
358
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 355

class CreateIndexRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#index_id::String

Returns Required. ID of the Index to create. The id must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.

Returns:

  • (::String)

    Required. ID of the Index to create. The id must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.



355
356
357
358
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 355

class CreateIndexRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the Collection for which to create the Index. Format: projects/{project}/locations/{location}/collections/{collection}.

Returns:

  • (::String)

    Required. The resource name of the Collection for which to create the Index. Format: projects/{project}/locations/{location}/collections/{collection}



355
356
357
358
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 355

class CreateIndexRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



355
356
357
358
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 355

class CreateIndexRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end