Class: Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb

Overview

REST client for the DataObjectSearchService service.

Service for searching data objects.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#collection_path, #index_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new DataObjectSearchService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the DataObjectSearchService client.

Yield Parameters:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 147

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @data_object_search_service_stub = ::Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @data_object_search_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @data_object_search_service_stub.endpoint
    config.universe_domain = @data_object_search_service_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @data_object_search_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


203
204
205
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 203

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the DataObjectSearchService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all DataObjectSearchService clients
::Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 65

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "VectorSearch", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.search_data_objects.timeout = 300.0
    default_config.rpcs.search_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.query_data_objects.timeout = 300.0
    default_config.rpcs.query_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.aggregate_data_objects.timeout = 300.0
    default_config.rpcs.aggregate_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.batch_search_data_objects.timeout = 300.0
    default_config.rpcs.batch_search_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#aggregate_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::AggregateDataObjectsResponse #aggregate_data_objects(parent: nil, filter: nil, aggregate: nil) ⇒ ::Google::Cloud::VectorSearch::V1::AggregateDataObjectsResponse

Aggregates data objects.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::AggregateDataObjectsRequest.new

# Call the aggregate_data_objects method.
result = client.aggregate_data_objects request

# The returned object is of type Google::Cloud::VectorSearch::V1::AggregateDataObjectsResponse.
p result

Overloads:

  • #aggregate_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::AggregateDataObjectsResponse

    Pass arguments to aggregate_data_objects via a request object, either of type AggregateDataObjectsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::AggregateDataObjectsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #aggregate_data_objects(parent: nil, filter: nil, aggregate: nil) ⇒ ::Google::Cloud::VectorSearch::V1::AggregateDataObjectsResponse

    Pass arguments to aggregate_data_objects via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection for which to query. Format: projects/{project}/locations/{location}/collections/{collection}

    • filter (::Google::Protobuf::Struct, ::Hash) (defaults to: nil)

      Optional. A JSON filter expression, e.g. {"genre": \{"$eq": "sci-fi"}}, represented as a google.protobuf.Struct.

    • aggregate (::Google::Cloud::VectorSearch::V1::AggregationMethod) (defaults to: nil)

      Required. The aggregation method to apply to the query.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 473

def aggregate_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::AggregateDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.aggregate_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.aggregate_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.aggregate_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_search_service_stub.aggregate_data_objects request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_search_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsResponse #batch_search_data_objects(parent: nil, searches: nil, combine: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsResponse

Batch searches data objects.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsRequest.new

# Call the batch_search_data_objects method.
result = client.batch_search_data_objects request

# The returned object is of type Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 556

def batch_search_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchSearchDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_search_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_search_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_search_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_search_service_stub.batch_search_data_objects request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the DataObjectSearchService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



117
118
119
120
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 117

def configure
  yield @config if block_given?
  @config
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


210
211
212
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 210

def logger
  @data_object_search_service_stub.logger
end

#query_data_objects(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::DataObject> #query_data_objects(parent: nil, filter: nil, output_fields: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::DataObject>

Queries data objects.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::QueryDataObjectsRequest.new

# Call the query_data_objects method.
result = client.query_data_objects request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::VectorSearch::V1::DataObject.
  p item
end

Overloads:

  • #query_data_objects(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::DataObject>

    Pass arguments to query_data_objects via a request object, either of type QueryDataObjectsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::QueryDataObjectsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #query_data_objects(parent: nil, filter: nil, output_fields: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::DataObject>

    Pass arguments to query_data_objects via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection for which to query. Format: projects/{project}/locations/{location}/collections/{collection}

    • filter (::Google::Protobuf::Struct, ::Hash) (defaults to: nil)

      Optional. A JSON filter expression, e.g. {"genre": \{"$eq": "sci-fi"}}, represented as a google.protobuf.Struct.

    • output_fields (::Google::Cloud::VectorSearch::V1::OutputFields, ::Hash) (defaults to: nil)

      Optional. Mask specifying which fields to return.

    • page_size (::Integer) (defaults to: nil)

      Optional. The standard list page size. Default is 100. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. The standard list page token. Typically obtained via QueryDataObjectsResponse.next_page_token of the previous DataObjectSearchService.QueryDataObjects call.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 387

def query_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::QueryDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.query_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.query_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.query_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_search_service_stub.query_data_objects request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @data_object_search_service_stub, :query_data_objects, "data_objects", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#search_data_objects(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::SearchResult> #search_data_objects(vector_search: nil, semantic_search: nil, text_search: nil, parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::SearchResult>

Searches data objects.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectSearchService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::SearchDataObjectsRequest.new

# Call the search_data_objects method.
result = client.search_data_objects request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::VectorSearch::V1::SearchResult.
  p item
end

Overloads:

  • #search_data_objects(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::SearchResult>

    Pass arguments to search_data_objects via a request object, either of type SearchDataObjectsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::SearchDataObjectsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #search_data_objects(vector_search: nil, semantic_search: nil, text_search: nil, parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::VectorSearch::V1::SearchResult>

    Pass arguments to search_data_objects via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • vector_search (::Google::Cloud::VectorSearch::V1::VectorSearch, ::Hash) (defaults to: nil)

      A vector search operation.

      Note: The following parameters are mutually exclusive: vector_search, semantic_search, text_search. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • semantic_search (::Google::Cloud::VectorSearch::V1::SemanticSearch, ::Hash) (defaults to: nil)

      A semantic search operation.

      Note: The following parameters are mutually exclusive: semantic_search, vector_search, text_search. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • text_search (::Google::Cloud::VectorSearch::V1::TextSearch, ::Hash) (defaults to: nil)

      Optional. A text search operation.

      Note: The following parameters are mutually exclusive: text_search, vector_search, semantic_search. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection for which to search. Format: projects/{project}/locations/{location}/collections/{collection}

    • page_size (::Integer) (defaults to: nil)

      Optional. The standard list page size. Only supported for KNN. If not set, up to search_type.top_k results will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. The standard list page token. Typically obtained via SearchDataObjectsResponse.next_page_token of the previous DataObjectSearchService.SearchDataObjects call.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 287

def search_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::SearchDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.search_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.search_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.search_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_search_service_stub.search_data_objects request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @data_object_search_service_stub, :search_data_objects, "results", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


127
128
129
# File 'lib/google/cloud/vector_search/v1/data_object_search_service/rest/client.rb', line 127

def universe_domain
  @data_object_search_service_stub.universe_domain
end