Class: Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb

Overview

REST client for the DataObjectService service.

Service for creating and managing data objects.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#collection_path, #data_object_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new DataObjectService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the DataObjectService client.

Yield Parameters:



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 162

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @data_object_service_stub = ::Google::Cloud::VectorSearch::V1::DataObjectService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @data_object_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @data_object_service_stub.endpoint
    config.universe_domain = @data_object_service_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @data_object_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


218
219
220
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 218

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the DataObjectService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all DataObjectService clients
::Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 65

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "VectorSearch", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_data_object.timeout = 60.0
    default_config.rpcs.create_data_object.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.batch_create_data_objects.timeout = 300.0
    default_config.rpcs.batch_create_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_data_object.timeout = 60.0
    default_config.rpcs.get_data_object.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_data_object.timeout = 60.0
    default_config.rpcs.update_data_object.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.batch_update_data_objects.timeout = 60.0
    default_config.rpcs.batch_update_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.delete_data_object.timeout = 60.0
    default_config.rpcs.delete_data_object.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.batch_delete_data_objects.timeout = 60.0
    default_config.rpcs.batch_delete_data_objects.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#batch_create_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse #batch_create_data_objects(parent: nil, requests: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse

Creates a batch of dataObjects.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsRequest.new

# Call the batch_create_data_objects method.
result = client.batch_create_data_objects request

# The returned object is of type Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse.
p result

Overloads:

  • #batch_create_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse

    Pass arguments to batch_create_data_objects via a request object, either of type BatchCreateDataObjectsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_create_data_objects(parent: nil, requests: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse

    Pass arguments to batch_create_data_objects via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection to create the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}. The parent field in the CreateDataObjectRequest messages must match this field.

    • requests (::Array<::Google::Cloud::VectorSearch::V1::CreateDataObjectRequest, ::Hash>) (defaults to: nil)

      Required. The request message specifying the resources to create. A maximum of 1000 DataObjects can be created in a batch.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 367

def batch_create_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_create_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_create_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_create_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.batch_create_data_objects request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_delete_data_objects(request, options = nil) ⇒ ::Google::Protobuf::Empty #batch_delete_data_objects(parent: nil, requests: nil) ⇒ ::Google::Protobuf::Empty

Deletes dataObjects in a batch.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::BatchDeleteDataObjectsRequest.new

# Call the batch_delete_data_objects method.
result = client.batch_delete_data_objects request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #batch_delete_data_objects(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to batch_delete_data_objects via a request object, either of type BatchDeleteDataObjectsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::BatchDeleteDataObjectsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_delete_data_objects(parent: nil, requests: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to batch_delete_data_objects via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection to delete the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}.

    • requests (::Array<::Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest, ::Hash>) (defaults to: nil)

      Required. The request message specifying the resources to delete. A maximum of 1000 DataObjects can be deleted in a batch.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 778

def batch_delete_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchDeleteDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_delete_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_delete_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_delete_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.batch_delete_data_objects request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_update_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse #batch_update_data_objects(parent: nil, requests: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse

Updates dataObjects in a batch.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsRequest.new

# Call the batch_update_data_objects method.
result = client.batch_update_data_objects request

# The returned object is of type Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse.
p result

Overloads:

  • #batch_update_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse

    Pass arguments to batch_update_data_objects via a request object, either of type BatchUpdateDataObjectsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_update_data_objects(parent: nil, requests: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse

    Pass arguments to batch_update_data_objects via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection to update the DataObjects in. Format: projects/{project}/locations/{location}/collections/{collection}. The parent field in the UpdateDataObjectRequest messages must match this field.

    • requests (::Array<::Google::Cloud::VectorSearch::V1::UpdateDataObjectRequest, ::Hash>) (defaults to: nil)

      Required. The request message specifying the resources to update. A maximum of 1000 DataObjects can be updated in a batch.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 612

def batch_update_data_objects request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_update_data_objects..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_update_data_objects.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_update_data_objects.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.batch_update_data_objects request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the DataObjectService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



132
133
134
135
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 132

def configure
  yield @config if block_given?
  @config
end

#create_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject #create_data_object(parent: nil, data_object_id: nil, data_object: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

Creates a dataObject.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::CreateDataObjectRequest.new

# Call the create_data_object method.
result = client.create_data_object request

# The returned object is of type Google::Cloud::VectorSearch::V1::DataObject.
p result

Overloads:

  • #create_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

    Pass arguments to create_data_object via a request object, either of type CreateDataObjectRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::CreateDataObjectRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_data_object(parent: nil, data_object_id: nil, data_object: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

    Pass arguments to create_data_object via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the Collection to create the DataObject in. Format: projects/{project}/locations/{location}/collections/{collection}

    • data_object_id (::String) (defaults to: nil)

      Required. The id of the dataObject to create. The id must be 1-63 characters long, and comply with RFC1035. Specifically, it must be 1-63 characters long and match the regular expression [a-z](?:[-a-z0-9]{0,61}[a-z0-9])?.

    • data_object (::Google::Cloud::VectorSearch::V1::DataObject, ::Hash) (defaults to: nil)

      Required. The DataObject to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 283

def create_data_object request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::CreateDataObjectRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_data_object..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_data_object.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_data_object.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.create_data_object request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_data_object(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_object(name: nil, etag: nil) ⇒ ::Google::Protobuf::Empty

Deletes a dataObject.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest.new

# Call the delete_data_object method.
result = client.delete_data_object request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_data_object(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_data_object via a request object, either of type Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_data_object(name: nil, etag: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_data_object via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the DataObject resource to be deleted. Format: projects/{project}/locations/{location}/collections/{collection}/dataObjects/{dataObject}

    • etag (::String) (defaults to: nil)

      Optional. The current etag of the DataObject. If an etag is provided and does not match the current etag of the DataObject, deletion will be blocked and an ABORTED error will be returned.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 696

def delete_data_object request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_data_object..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_data_object.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_data_object.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.delete_data_object request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject #get_data_object(name: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

Gets a data object.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::GetDataObjectRequest.new

# Call the get_data_object method.
result = client.get_data_object request

# The returned object is of type Google::Cloud::VectorSearch::V1::DataObject.
p result

Overloads:

  • #get_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

    Pass arguments to get_data_object via a request object, either of type GetDataObjectRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::VectorSearch::V1::GetDataObjectRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_data_object(name: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

    Pass arguments to get_data_object via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the DataObject resource. Format: projects/{project}/locations/{location}/collections/{collection}/dataObjects/{dataObject}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 447

def get_data_object request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::GetDataObjectRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_data_object..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_data_object.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_data_object.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.get_data_object request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


225
226
227
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 225

def logger
  @data_object_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


142
143
144
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 142

def universe_domain
  @data_object_service_stub.universe_domain
end

#update_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject #update_data_object(data_object: nil, update_mask: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject

Updates a dataObject.

Examples:

Basic example

require "google/cloud/vector_search/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::VectorSearch::V1::DataObjectService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::VectorSearch::V1::UpdateDataObjectRequest.new

# Call the update_data_object method.
result = client.update_data_object request

# The returned object is of type Google::Cloud::VectorSearch::V1::DataObject.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/google/cloud/vector_search/v1/data_object_service/rest/client.rb', line 528

def update_data_object request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::UpdateDataObjectRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_data_object..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_data_object.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_data_object.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_object_service_stub.update_data_object request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end