Class: Google::Cloud::VectorSearch::V1::DedicatedInfrastructure

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb

Overview

Represents dedicated infrastructure for the index.

Defined Under Namespace

Modules: Mode Classes: AutoscalingSpec

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaling_spec::Google::Cloud::VectorSearch::V1::DedicatedInfrastructure::AutoscalingSpec

Returns Optional. Autoscaling specification.

Returns:



665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 665

class DedicatedInfrastructure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specification for autoscaling.
  # @!attribute [rw] min_replica_count
  #   @return [::Integer]
  #     Optional. The minimum number of replicas. If not set or set to `0`,
  #     defaults to `2`. Must be >= `1` and <= `1000`.
  # @!attribute [rw] max_replica_count
  #   @return [::Integer]
  #     Optional. The maximum number of replicas.  Must be >=
  #     `min_replica_count` and <= `1000`.
  #     For the v1beta version, if not set or set to `0`, defaults to
  #     the greater of `min_replica_count` and `5`.
  #     For all other versions, if not set or set to `0`, defaults to
  #     the greater of `min_replica_count` and `2`.
  class AutoscalingSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Mode of the dedicated infrastructure.
  module Mode
    # Default will use `PERFORMANCE_OPTIMIZED`.
    MODE_UNSPECIFIED = 0

    # This is storage optimized variation.
    STORAGE_OPTIMIZED = 1

    # This is Performance optimized on E2 or equivalent family.
    PERFORMANCE_OPTIMIZED = 2
  end
end

#mode::Google::Cloud::VectorSearch::V1::DedicatedInfrastructure::Mode

Returns Optional. Mode of the dedicated infrastructure.

Returns:



665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 665

class DedicatedInfrastructure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specification for autoscaling.
  # @!attribute [rw] min_replica_count
  #   @return [::Integer]
  #     Optional. The minimum number of replicas. If not set or set to `0`,
  #     defaults to `2`. Must be >= `1` and <= `1000`.
  # @!attribute [rw] max_replica_count
  #   @return [::Integer]
  #     Optional. The maximum number of replicas.  Must be >=
  #     `min_replica_count` and <= `1000`.
  #     For the v1beta version, if not set or set to `0`, defaults to
  #     the greater of `min_replica_count` and `5`.
  #     For all other versions, if not set or set to `0`, defaults to
  #     the greater of `min_replica_count` and `2`.
  class AutoscalingSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Mode of the dedicated infrastructure.
  module Mode
    # Default will use `PERFORMANCE_OPTIMIZED`.
    MODE_UNSPECIFIED = 0

    # This is storage optimized variation.
    STORAGE_OPTIMIZED = 1

    # This is Performance optimized on E2 or equivalent family.
    PERFORMANCE_OPTIMIZED = 2
  end
end