Class: Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb

Overview

Request message for DataObjectService.DeleteDataObject.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the DataObject. If an etag is provided and does not match the current etag of the DataObject, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the DataObject. If an etag is provided and does not match the current etag of the DataObject, deletion will be blocked and an ABORTED error will be returned.



134
135
136
137
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 134

class DeleteDataObjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the DataObject resource to be deleted. Format: projects/{project}/locations/{location}/collections/{collection}/dataObjects/{dataObject}.

Returns:

  • (::String)

    Required. The name of the DataObject resource to be deleted. Format: projects/{project}/locations/{location}/collections/{collection}/dataObjects/{dataObject}



134
135
136
137
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_service.rb', line 134

class DeleteDataObjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end