Class: Google::Cloud::VectorSearch::V1::EncryptionSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/encryption_spec.rb

Overview

Represents a customer-managed encryption key specification that can be applied to a Vector Search collection.

Instance Attribute Summary collapse

Instance Attribute Details

#crypto_key_name::String

Returns Required. Resource name of the Cloud KMS key used to protect the resource.

The Cloud KMS key must be in the same region as the resource. It must have the format projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.

Returns:

  • (::String)

    Required. Resource name of the Cloud KMS key used to protect the resource.

    The Cloud KMS key must be in the same region as the resource. It must have the format projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.



33
34
35
36
# File 'proto_docs/google/cloud/vectorsearch/v1/encryption_spec.rb', line 33

class EncryptionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end