Class: Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb

Overview

Google Cloud Storage configuration for the export.

Defined Under Namespace

Modules: Format

Instance Attribute Summary collapse

Instance Attribute Details

#export_uri::String

Returns Required. URI prefix of the Cloud Storage where to export Data Objects. The bucket is required to be in the same region as the collection.

Returns:

  • (::String)

    Required. URI prefix of the Cloud Storage where to export Data Objects. The bucket is required to be in the same region as the collection.



595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 595

class GcsExportDestination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for the format of the exported Data Objects.
  module Format
    # Unspecified format.
    FORMAT_UNSPECIFIED = 0

    # Exports Data Objects in `JSONL` format.
    JSONL = 2
  end
end

#format::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination::Format

Returns Required. The format of the exported Data Objects.

Returns:



595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 595

class GcsExportDestination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for the format of the exported Data Objects.
  module Format
    # Unspecified format.
    FORMAT_UNSPECIFIED = 0

    # Exports Data Objects in `JSONL` format.
    JSONL = 2
  end
end