Class: Google::Cloud::VectorSearch::V1::Index

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb

Overview

Message describing Index object

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Create time stamp.

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dedicated_infrastructure::Google::Cloud::VectorSearch::V1::DedicatedInfrastructure

Returns Optional. Dedicated infrastructure for the index.

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dense_scann::Google::Cloud::VectorSearch::V1::DenseScannIndex

Returns Optional. Dense ScaNN index.

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. User-specified description of the index.

Returns:

  • (::String)

    Optional. User-specified description of the index



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. User-specified display name of the index.

Returns:

  • (::String)

    Optional. User-specified display name of the index



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#distance_metric::Google::Cloud::VectorSearch::V1::DistanceMetric

Returns Optional. Distance metric used for indexing. If not specified, will default to DOT_PRODUCT.

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#filter_fields::Array<::String>

Returns Optional. The fields to push into the index to enable fast ANN inline filtering.

Returns:

  • (::Array<::String>)

    Optional. The fields to push into the index to enable fast ANN inline filtering.



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#index_field::String

Returns Required. The collection schema field to index.

Returns:

  • (::String)

    Required. The collection schema field to index.



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels as key value pairs.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels as key value pairs.



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. name of resource.

Returns:

  • (::String)

    Identifier. name of resource



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#store_fields::Array<::String>

Returns Optional. The fields to push into the index to enable inline data retrieval.

Returns:

  • (::Array<::String>)

    Optional. The fields to push into the index to enable inline data retrieval.



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Update time stamp.

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 310

class Index
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end