Class: Google::Cloud::VectorSearch::V1::ListCollectionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::ListCollectionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Message for response to listing Collections
Instance Attribute Summary collapse
-
#collections ⇒ ::Array<::Google::Cloud::VectorSearch::V1::Collection>
The list of Collection.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Unordered list.
Instance Attribute Details
#collections ⇒ ::Array<::Google::Cloud::VectorSearch::V1::Collection>
Returns The list of Collection.
150 151 152 153 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 150 class ListCollectionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
150 151 152 153 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 150 class ListCollectionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. Locations that could not be reached.
150 151 152 153 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 150 class ListCollectionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |