Class: Google::Cloud::VectorSearch::V1::OutputFields

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

Defines a output fields struct for data in DataObject.

Instance Attribute Summary collapse

Instance Attribute Details

#data_fields::Array<::String>

Returns Optional. The fields from the data fields to include in the output.

Returns:

  • (::Array<::String>)

    Optional. The fields from the data fields to include in the output.



34
35
36
37
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 34

class OutputFields
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metadata_fields::Array<::String>

Returns Optional. The fields from the DataObject metadata to include in the output.

Returns:

  • (::Array<::String>)

    Optional. The fields from the DataObject metadata to include in the output.



34
35
36
37
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 34

class OutputFields
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vector_fields::Array<::String>

Returns Optional. The fields from the vector fields to include in the output.

Returns:

  • (::Array<::String>)

    Optional. The fields from the vector fields to include in the output.



34
35
36
37
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 34

class OutputFields
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end