Class: Google::Cloud::VectorSearch::V1::QueryDataObjectsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#filter::Google::Protobuf::Struct

Returns Optional. A JSON filter expression, e.g. {"genre": \{"$eq": "sci-fi"}}, represented as a google.protobuf.Struct.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. A JSON filter expression, e.g. {"genre": \{"$eq": "sci-fi"}}, represented as a google.protobuf.Struct.



306
307
308
309
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 306

class QueryDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_fields::Google::Cloud::VectorSearch::V1::OutputFields

Returns Optional. Mask specifying which fields to return.

Returns:



306
307
308
309
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 306

class QueryDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The standard list page size. Default is 100. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The standard list page size. Default is 100. The maximum value is 1000; values above 1000 will be coerced to 1000.



306
307
308
309
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 306

class QueryDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The standard list page token. Typically obtained via QueryDataObjectsResponse.next_page_token of the previous DataObjectSearchService.QueryDataObjects call.

Returns:



306
307
308
309
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 306

class QueryDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the Collection for which to query. Format: projects/{project}/locations/{location}/collections/{collection}.

Returns:

  • (::String)

    Required. The resource name of the Collection for which to query. Format: projects/{project}/locations/{location}/collections/{collection}



306
307
308
309
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 306

class QueryDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end