Class: Google::Cloud::VectorSearch::V1::Search

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

A single search request within a batch operation.

Instance Attribute Summary collapse

Instance Attribute Details

#semantic_search::Google::Cloud::VectorSearch::V1::SemanticSearch

Returns A semantic search.

Note: The following fields are mutually exclusive: semantic_search, vector_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::SemanticSearch)

    A semantic search.

    Note: The following fields are mutually exclusive: semantic_search, vector_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.



91
92
93
94
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 91

class Search
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_search::Google::Cloud::VectorSearch::V1::TextSearch

Returns A text search operation.

Note: The following fields are mutually exclusive: text_search, vector_search, semantic_search. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::TextSearch)

    A text search operation.

    Note: The following fields are mutually exclusive: text_search, vector_search, semantic_search. If a field in that set is populated, all other fields in the set will automatically be cleared.



91
92
93
94
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 91

class Search
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vector_search::Google::Cloud::VectorSearch::V1::VectorSearch

Returns A vector-based search.

Note: The following fields are mutually exclusive: vector_search, semantic_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::VectorSearch)

    A vector-based search.

    Note: The following fields are mutually exclusive: vector_search, semantic_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.



91
92
93
94
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 91

class Search
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end