Class: Google::Cloud::VectorSearch::V1::SearchDataObjectsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

Request for performing a single search.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The standard list page size. Only supported for KNN. If not set, up to search_type.top_k results will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The standard list page size. Only supported for KNN. If not set, up to search_type.top_k results will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



221
222
223
224
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 221

class SearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The standard list page token. Typically obtained via SearchDataObjectsResponse.next_page_token of the previous DataObjectSearchService.SearchDataObjects call.

Returns:



221
222
223
224
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 221

class SearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the Collection for which to search. Format: projects/{project}/locations/{location}/collections/{collection}.

Returns:

  • (::String)

    Required. The resource name of the Collection for which to search. Format: projects/{project}/locations/{location}/collections/{collection}



221
222
223
224
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 221

class SearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#semantic_search::Google::Cloud::VectorSearch::V1::SemanticSearch

Returns A semantic search operation.

Note: The following fields are mutually exclusive: semantic_search, vector_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::SemanticSearch)

    A semantic search operation.

    Note: The following fields are mutually exclusive: semantic_search, vector_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.



221
222
223
224
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 221

class SearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_search::Google::Cloud::VectorSearch::V1::TextSearch

Returns Optional. A text search operation.

Note: The following fields are mutually exclusive: text_search, vector_search, semantic_search. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::TextSearch)

    Optional. A text search operation.

    Note: The following fields are mutually exclusive: text_search, vector_search, semantic_search. If a field in that set is populated, all other fields in the set will automatically be cleared.



221
222
223
224
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 221

class SearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vector_search::Google::Cloud::VectorSearch::V1::VectorSearch

Returns A vector search operation.

Note: The following fields are mutually exclusive: vector_search, semantic_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::VectorSearch)

    A vector search operation.

    Note: The following fields are mutually exclusive: vector_search, semantic_search, text_search. If a field in that set is populated, all other fields in the set will automatically be cleared.



221
222
223
224
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 221

class SearchDataObjectsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end