Class: Google::Cloud::VectorSearch::V1::SearchHint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

Represents a hint to the search index engine.

Defined Under Namespace

Classes: IndexHint, KnnHint

Instance Attribute Summary collapse

Instance Attribute Details

#index_hint::Google::Cloud::VectorSearch::V1::SearchHint::IndexHint

Returns Optional. Specifies that the search should use a particular index.

Note: The following fields are mutually exclusive: index_hint, knn_hint. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::SearchHint::IndexHint)

    Optional. Specifies that the search should use a particular index.

    Note: The following fields are mutually exclusive: index_hint, knn_hint. If a field in that set is populated, all other fields in the set will automatically be cleared.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 51

class SearchHint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Message to specify the index to use for the search.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. The resource name of the index to use for the search.
  #     The index must be in the same project, location, and collection.
  #     Format:
  #     `projects/{project}/locations/{location}/collections/{collection}/indexes/{index}`
  class IndexHint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KnnHint will be used if search should be explicitly done on system's
  # default K-Nearest Neighbor (KNN) index engine.
  class KnnHint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#knn_hint::Google::Cloud::VectorSearch::V1::SearchHint::KnnHint

Returns Optional. If set, the search will use the system's default K-Nearest Neighbor (KNN) index engine.

Note: The following fields are mutually exclusive: knn_hint, index_hint. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::SearchHint::KnnHint)

    Optional. If set, the search will use the system's default K-Nearest Neighbor (KNN) index engine.

    Note: The following fields are mutually exclusive: knn_hint, index_hint. If a field in that set is populated, all other fields in the set will automatically be cleared.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 51

class SearchHint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Message to specify the index to use for the search.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. The resource name of the index to use for the search.
  #     The index must be in the same project, location, and collection.
  #     Format:
  #     `projects/{project}/locations/{location}/collections/{collection}/indexes/{index}`
  class IndexHint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KnnHint will be used if search should be explicitly done on system's
  # default K-Nearest Neighbor (KNN) index engine.
  class KnnHint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end