Class: Google::Cloud::VectorSearch::V1::SearchHint::IndexHint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb

Overview

Message to specify the index to use for the search.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the index to use for the search. The index must be in the same project, location, and collection. Format: projects/{project}/locations/{location}/collections/{collection}/indexes/{index}.

Returns:

  • (::String)

    Required. The resource name of the index to use for the search. The index must be in the same project, location, and collection. Format: projects/{project}/locations/{location}/collections/{collection}/indexes/{index}



62
63
64
65
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object_search_service.rb', line 62

class IndexHint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end