Class: Google::Cloud::VectorSearch::V1::UpdateCollectionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::UpdateCollectionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Message for updating a Collection
Instance Attribute Summary collapse
-
#collection ⇒ ::Google::Cloud::VectorSearch::V1::Collection
Required.
-
#request_id ⇒ ::String
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#collection ⇒ ::Google::Cloud::VectorSearch::V1::Collection
Returns Required. The resource being updated.
236 237 238 239 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 236 class UpdateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
236 237 238 239 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 236 class UpdateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the Collection resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields present in the request will be overwritten.
The following fields support update: display_name, description,
labels, data_schema, vector_schema.
For data_schema and vector_schema, fields can only be added, not
deleted, but vertex_embedding_config in vector_schema can be added or
removed.
Partial updates for data_schema and vector_schema are also supported
by using sub-field paths in update_mask, e.g.
data_schema.properties.foo or vector_schema.my_vector_field.
If * is provided in the update_mask, full replacement will be performed.
236 237 238 239 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 236 class UpdateCollectionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |