Class: Google::Cloud::VectorSearch::V1::Vector

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/vectorsearch/v1/data_object.rb

Overview

A vector which can be either dense or sparse.

Instance Attribute Summary collapse

Instance Attribute Details

#dense::Google::Cloud::VectorSearch::V1::DenseVector

Returns A dense vector.

Note: The following fields are mutually exclusive: dense, sparse. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VectorSearch::V1::DenseVector)

    A dense vector.

    Note: The following fields are mutually exclusive: dense, sparse. If a field in that set is populated, all other fields in the set will automatically be cleared.



76
77
78
79
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object.rb', line 76

class Vector
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sparse::Google::Cloud::VectorSearch::V1::SparseVector

Returns A sparse vector.

Note: The following fields are mutually exclusive: sparse, dense. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



76
77
78
79
# File 'proto_docs/google/cloud/vectorsearch/v1/data_object.rb', line 76

class Vector
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end