Class: Google::Cloud::VectorSearch::V1::DataObjectService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::DataObjectService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/vector_search/v1/data_object_service/client.rb
Overview
Client for the DataObjectService service.
Service for creating and managing data objects.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataObjectService Client class.
Instance Method Summary collapse
-
#batch_create_data_objects(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse
Creates a batch of dataObjects.
-
#batch_delete_data_objects(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes dataObjects in a batch.
-
#batch_update_data_objects(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse
Updates dataObjects in a batch.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataObjectService Client instance.
-
#create_data_object(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::VectorSearch::V1::DataObject
Creates a dataObject.
-
#delete_data_object(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a dataObject.
-
#get_data_object(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::VectorSearch::V1::DataObject
Gets a data object.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new DataObjectService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_data_object(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::VectorSearch::V1::DataObject
Updates a dataObject.
Methods included from Paths
#collection_path, #data_object_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new DataObjectService client object.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 160 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/vectorsearch/v1/data_object_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @data_object_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::VectorSearch::V1::DataObjectService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @data_object_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @data_object_service_stub.endpoint config.universe_domain = @data_object_service_stub.universe_domain config.logger = @data_object_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
224 225 226 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 224 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataObjectService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "VectorSearch", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_data_object.timeout = 60.0 default_config.rpcs.create_data_object.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.batch_create_data_objects.timeout = 300.0 default_config.rpcs.batch_create_data_objects.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_data_object.timeout = 60.0 default_config.rpcs.get_data_object.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_object.timeout = 60.0 default_config.rpcs.update_data_object.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.batch_update_data_objects.timeout = 60.0 default_config.rpcs.batch_update_data_objects.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.delete_data_object.timeout = 60.0 default_config.rpcs.delete_data_object.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.batch_delete_data_objects.timeout = 60.0 default_config.rpcs.batch_delete_data_objects.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#batch_create_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse #batch_create_data_objects(parent: nil, requests: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsResponse
Creates a batch of dataObjects.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 381 def batch_create_data_objects request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchCreateDataObjectsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_create_data_objects..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.batch_create_data_objects.timeout, metadata: , retry_policy: @config.rpcs.batch_create_data_objects.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :batch_create_data_objects, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_delete_data_objects(request, options = nil) ⇒ ::Google::Protobuf::Empty #batch_delete_data_objects(parent: nil, requests: nil) ⇒ ::Google::Protobuf::Empty
Deletes dataObjects in a batch.
827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 827 def batch_delete_data_objects request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchDeleteDataObjectsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_delete_data_objects..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.batch_delete_data_objects.timeout, metadata: , retry_policy: @config.rpcs.batch_delete_data_objects.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :batch_delete_data_objects, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_update_data_objects(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse #batch_update_data_objects(parent: nil, requests: nil) ⇒ ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsResponse
Updates dataObjects in a batch.
647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 647 def batch_update_data_objects request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::BatchUpdateDataObjectsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_update_data_objects..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.batch_update_data_objects.timeout, metadata: , retry_policy: @config.rpcs.batch_update_data_objects.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :batch_update_data_objects, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataObjectService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
130 131 132 133 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 130 def configure yield @config if block_given? @config end |
#create_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject #create_data_object(parent: nil, data_object_id: nil, data_object: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject
Creates a dataObject.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 290 def create_data_object request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::CreateDataObjectRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_object..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_data_object.timeout, metadata: , retry_policy: @config.rpcs.create_data_object.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :create_data_object, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_object(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_object(name: nil, etag: nil) ⇒ ::Google::Protobuf::Empty
Deletes a dataObject.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 738 def delete_data_object request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::DeleteDataObjectRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_object..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_data_object.timeout, metadata: , retry_policy: @config.rpcs.delete_data_object.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :delete_data_object, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject #get_data_object(name: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject
Gets a data object.
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 468 def get_data_object request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::GetDataObjectRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_object..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_data_object.timeout, metadata: , retry_policy: @config.rpcs.get_data_object.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :get_data_object, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
231 232 233 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 231 def logger @data_object_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
140 141 142 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 140 def universe_domain @data_object_service_stub.universe_domain end |
#update_data_object(request, options = nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject #update_data_object(data_object: nil, update_mask: nil) ⇒ ::Google::Cloud::VectorSearch::V1::DataObject
Updates a dataObject.
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/google/cloud/vector_search/v1/data_object_service/client.rb', line 556 def update_data_object request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::VectorSearch::V1::UpdateDataObjectRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_object..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::VectorSearch::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.data_object&.name header_params["data_object.name"] = request.data_object.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_data_object.timeout, metadata: , retry_policy: @config.rpcs.update_data_object.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_object_service_stub.call_rpc :update_data_object, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |