Class: Google::Cloud::VectorSearch::V1::DedicatedInfrastructure::AutoscalingSpec
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::DedicatedInfrastructure::AutoscalingSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Specification for autoscaling.
Instance Attribute Summary collapse
-
#max_replica_count ⇒ ::Integer
Optional.
-
#min_replica_count ⇒ ::Integer
Optional.
Instance Attribute Details
#max_replica_count ⇒ ::Integer
Returns Optional. The maximum number of replicas. Must be >=
min_replica_count and <= 1000.
For the v1beta version, if not set or set to 0, defaults to
the greater of min_replica_count and 5.
For all other versions, if not set or set to 0, defaults to
the greater of min_replica_count and 2.
682 683 684 685 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 682 class AutoscalingSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_replica_count ⇒ ::Integer
Returns Optional. The minimum number of replicas. If not set or set to 0,
defaults to 2. Must be >= 1 and <= 1000.
682 683 684 685 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 682 class AutoscalingSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |