Class: Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Request message for VectorSearchService.ExportDataObjects.
Defined Under Namespace
Classes: FieldFilter, GcsExportDestination
Instance Attribute Summary collapse
-
#field_filter ⇒ ::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter
Optional.
-
#gcs_destination ⇒ ::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination
The Cloud Storage location where user wants to export Data Objects.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#field_filter ⇒ ::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter
Returns Optional. Restricts which top-level Data Object fields appear in each
exported JSONL record. If unset, every field is exported (the existing
behavior). The primary use case is excluding the per-object etag so
that the exported records can be imported into a Collection in a
different region without optimistic-concurrency conflicts.
Allowed field names are id, data, vectors, etag.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 583 class ExportDataObjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Google Cloud Storage configuration for the export. # @!attribute [rw] export_uri # @return [::String] # Required. URI prefix of the Cloud Storage where to export Data Objects. # The bucket is required to be in the same region as the collection. # @!attribute [rw] format # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination::Format] # Required. The format of the exported Data Objects. class GcsExportDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for the format of the exported Data Objects. module Format # Unspecified format. FORMAT_UNSPECIFIED = 0 # Exports Data Objects in `JSONL` format. JSONL = 2 end end # Selects which top-level Data Object fields are emitted at export time. # @!attribute [rw] included_fields # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter::FieldList] # Optional. Only these top-level fields will appear in each exported # record. # # Note: The following fields are mutually exclusive: `included_fields`, `excluded_fields`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] excluded_fields # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter::FieldList] # Optional. Every top-level field except these will appear in each # exported record. # # Note: The following fields are mutually exclusive: `excluded_fields`, `included_fields`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FieldFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Wrapper for a repeated string. Wrapping in a message lets the # surrounding `oneof` distinguish "field set to an empty list" (which is # rejected as INVALID_ARGUMENT) from "field not set". # @!attribute [rw] fields # @return [::Array<::String>] # Required. The list of top-level Data Object JSON field names. Allowed # values are `id`, `data`, `vectors`, `etag`. class FieldList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#gcs_destination ⇒ ::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination
Returns The Cloud Storage location where user wants to export Data Objects.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 583 class ExportDataObjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Google Cloud Storage configuration for the export. # @!attribute [rw] export_uri # @return [::String] # Required. URI prefix of the Cloud Storage where to export Data Objects. # The bucket is required to be in the same region as the collection. # @!attribute [rw] format # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination::Format] # Required. The format of the exported Data Objects. class GcsExportDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for the format of the exported Data Objects. module Format # Unspecified format. FORMAT_UNSPECIFIED = 0 # Exports Data Objects in `JSONL` format. JSONL = 2 end end # Selects which top-level Data Object fields are emitted at export time. # @!attribute [rw] included_fields # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter::FieldList] # Optional. Only these top-level fields will appear in each exported # record. # # Note: The following fields are mutually exclusive: `included_fields`, `excluded_fields`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] excluded_fields # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter::FieldList] # Optional. Every top-level field except these will appear in each # exported record. # # Note: The following fields are mutually exclusive: `excluded_fields`, `included_fields`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FieldFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Wrapper for a repeated string. Wrapping in a message lets the # surrounding `oneof` distinguish "field set to an empty list" (which is # rejected as INVALID_ARGUMENT) from "field not set". # @!attribute [rw] fields # @return [::Array<::String>] # Required. The list of top-level Data Object JSON field names. Allowed # values are `id`, `data`, `vectors`, `etag`. class FieldList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#name ⇒ ::String
Returns Required. The resource name of the Collection from which we want to export
Data Objects. Format:
projects/{project}/locations/{location}/collections/{collection}.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 583 class ExportDataObjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Google Cloud Storage configuration for the export. # @!attribute [rw] export_uri # @return [::String] # Required. URI prefix of the Cloud Storage where to export Data Objects. # The bucket is required to be in the same region as the collection. # @!attribute [rw] format # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::GcsExportDestination::Format] # Required. The format of the exported Data Objects. class GcsExportDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for the format of the exported Data Objects. module Format # Unspecified format. FORMAT_UNSPECIFIED = 0 # Exports Data Objects in `JSONL` format. JSONL = 2 end end # Selects which top-level Data Object fields are emitted at export time. # @!attribute [rw] included_fields # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter::FieldList] # Optional. Only these top-level fields will appear in each exported # record. # # Note: The following fields are mutually exclusive: `included_fields`, `excluded_fields`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] excluded_fields # @return [::Google::Cloud::VectorSearch::V1::ExportDataObjectsRequest::FieldFilter::FieldList] # Optional. Every top-level field except these will appear in each # exported record. # # Note: The following fields are mutually exclusive: `excluded_fields`, `included_fields`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FieldFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Wrapper for a repeated string. Wrapping in a message lets the # surrounding `oneof` distinguish "field set to an empty list" (which is # rejected as INVALID_ARGUMENT) from "field not set". # @!attribute [rw] fields # @return [::Array<::String>] # Required. The list of top-level Data Object JSON field names. Allowed # values are `id`, `data`, `vectors`, `etag`. class FieldList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |