Class: Google::Cloud::VectorSearch::V1::ImportDataObjectsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::ImportDataObjectsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Request message for VectorSearchService.ImportDataObjects.
Defined Under Namespace
Classes: GcsImportConfig
Instance Attribute Summary collapse
-
#gcs_import ⇒ ::Google::Cloud::VectorSearch::V1::ImportDataObjectsRequest::GcsImportConfig
The Cloud Storage location of the input content.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#gcs_import ⇒ ::Google::Cloud::VectorSearch::V1::ImportDataObjectsRequest::GcsImportConfig
Returns The Cloud Storage location of the input content.
511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 511 class ImportDataObjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Google Cloud Storage configuration for the import. # @!attribute [rw] contents_uri # @return [::String] # Required. URI prefix of the Cloud Storage DataObjects to import. # @!attribute [rw] error_uri # @return [::String] # Required. URI prefix of the Cloud Storage location to write any errors # encountered during the import. # @!attribute [rw] output_uri # @return [::String] # Optional. URI prefix of the Cloud Storage location to write DataObject # `IDs` and `etags` of DataObjects that were successfully imported. The # service will write the successfully imported DataObjects to sharded files # under this prefix. If this field is empty, no output will be written. class GcsImportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The resource name of the Collection to import DataObjects into.
Format: projects/{project}/locations/{location}/collections/{collection}.
511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 511 class ImportDataObjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Google Cloud Storage configuration for the import. # @!attribute [rw] contents_uri # @return [::String] # Required. URI prefix of the Cloud Storage DataObjects to import. # @!attribute [rw] error_uri # @return [::String] # Required. URI prefix of the Cloud Storage location to write any errors # encountered during the import. # @!attribute [rw] output_uri # @return [::String] # Optional. URI prefix of the Cloud Storage location to write DataObject # `IDs` and `etags` of DataObjects that were successfully imported. The # service will write the successfully imported DataObjects to sharded files # under this prefix. If this field is empty, no output will be written. class GcsImportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |