Class: Google::Cloud::VectorSearch::V1::ImportDataObjectsRequest::GcsImportConfig
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::ImportDataObjectsRequest::GcsImportConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Google Cloud Storage configuration for the import.
Instance Attribute Summary collapse
-
#contents_uri ⇒ ::String
Required.
-
#error_uri ⇒ ::String
Required.
-
#output_uri ⇒ ::String
Optional.
Instance Attribute Details
#contents_uri ⇒ ::String
Returns Required. URI prefix of the Cloud Storage DataObjects to import.
529 530 531 532 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 529 class GcsImportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_uri ⇒ ::String
Returns Required. URI prefix of the Cloud Storage location to write any errors encountered during the import.
529 530 531 532 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 529 class GcsImportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_uri ⇒ ::String
Returns Optional. URI prefix of the Cloud Storage location to write DataObject
IDs and etags of DataObjects that were successfully imported. The
service will write the successfully imported DataObjects to sharded files
under this prefix. If this field is empty, no output will be written.
529 530 531 532 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 529 class GcsImportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |