Class: Google::Cloud::VectorSearch::V1::ListIndexesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::ListIndexesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Message for response to listing Indexes
Instance Attribute Summary collapse
-
#indexes ⇒ ::Array<::Google::Cloud::VectorSearch::V1::Index>
The list of Index.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
Instance Attribute Details
#indexes ⇒ ::Array<::Google::Cloud::VectorSearch::V1::Index>
Returns The list of Index.
456 457 458 459 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 456 class ListIndexesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
456 457 458 459 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 456 class ListIndexesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |