Class: Google::Cloud::VectorSearch::V1::VectorField
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::VectorField
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb
Overview
Message describing a vector field.
Instance Attribute Summary collapse
-
#dense_vector ⇒ ::Google::Cloud::VectorSearch::V1::DenseVectorField
Dense vector field.
-
#sparse_vector ⇒ ::Google::Cloud::VectorSearch::V1::SparseVectorField
Sparse vector field.
Instance Attribute Details
#dense_vector ⇒ ::Google::Cloud::VectorSearch::V1::DenseVectorField
Returns Dense vector field.
Note: The following fields are mutually exclusive: dense_vector, sparse_vector. If a field in that set is populated, all other fields in the set will automatically be cleared.
94 95 96 97 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 94 class VectorField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sparse_vector ⇒ ::Google::Cloud::VectorSearch::V1::SparseVectorField
Returns Sparse vector field.
Note: The following fields are mutually exclusive: sparse_vector, dense_vector. If a field in that set is populated, all other fields in the set will automatically be cleared.
94 95 96 97 |
# File 'proto_docs/google/cloud/vectorsearch/v1/vectorsearch_service.rb', line 94 class VectorField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |