Class: Google::Cloud::VectorSearch::V1::VertexEmbeddingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::VectorSearch::V1::VertexEmbeddingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/vectorsearch/v1/embedding_config.rb
Overview
Message describing the configuration for generating embeddings for a vector field using Vertex AI embeddings API.
Instance Attribute Summary collapse
-
#model_id ⇒ ::String
Required.
-
#task_type ⇒ ::Google::Cloud::VectorSearch::V1::EmbeddingTaskType
Required.
-
#text_template ⇒ ::String
Required.
Instance Attribute Details
#model_id ⇒ ::String
Returns Required. Required: ID of the embedding model to use. See https://cloud.google.com/vertex-ai/generative-ai/docs/learn/models#embeddings-models for the list of supported models.
39 40 41 42 |
# File 'proto_docs/google/cloud/vectorsearch/v1/embedding_config.rb', line 39 class VertexEmbeddingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#task_type ⇒ ::Google::Cloud::VectorSearch::V1::EmbeddingTaskType
Returns Required. Required: Task type for the embeddings.
39 40 41 42 |
# File 'proto_docs/google/cloud/vectorsearch/v1/embedding_config.rb', line 39 class VertexEmbeddingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text_template ⇒ ::String
Returns Required. Required: Text template for the input to the model. The template must contain one or more references to fields in the DataObject, e.g.: "Movie Title: {title} ---- Movie Plot: {plot}".
39 40 41 42 |
# File 'proto_docs/google/cloud/vectorsearch/v1/embedding_config.rb', line 39 class VertexEmbeddingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |